@@ -20,6 +20,7 @@ define([
             , DEF_BLOCK_ARG4_TYPE
 
             , FOR_BLOCK_ARG3_TYPE
+            , WHILE_BLOCK_TYPE 
 
             , NUM_FONT_WEIGHT_300
             , NUM_FONT_WEIGHT_700
@@ -94,7 +95,10 @@ define([
             , STATE_listforPrevExpression
  
             , STATE_whileCodeLine
- 
+            , STATE_whileBlockOptionType
+            , STATE_whileArgs
+            , STATE_whileConditionList
+
             , STATE_breakCodeLine
             , STATE_passCodeLine
             , STATE_continueCodeLine
@@ -254,13 +258,18 @@ define([
              const { conditionType } = ifCondition;
              if (conditionType == IF_BLOCK_CONDITION_TYPE.ARG) {
                  const { arg1, arg2, arg3, arg4, arg5, arg6 } = ifCondition;
-                 if (arg1 == '' && arg2 == '' && arg3 == ''&& (arg4 == 'none' || arg4 == '')) {
-                     return;
-                 }
- 
-                 ifConditionListStr += `(`;
+                //  if (arg1 == '' && arg2 == '' && arg3 == ''&& (arg4 == 'none' || arg4 == '')) {
+                //      return;
+                //  }
+                if ( !(arg1 == '' && (arg2 == 'none' || arg2 == '') && arg3 == '')) {
+                    ifConditionListStr += `(`;
+                }
+                //  ifConditionListStr += `(`;
                  ifConditionListStr += arg1;
-                 ifConditionListStr += arg2;
+  
+                 if ( arg2 !== 'none' ) {
+                    ifConditionListStr += arg2;
+                 }
                  ifConditionListStr += arg3;
          
                  if ( arg4 !== 'none' ) {
@@ -268,7 +277,9 @@ define([
                      ifConditionListStr += arg5;
                  }
                  
-                 ifConditionListStr += `)`;
+                 if ( !(arg1 == '' && (arg2 == 'none' || arg2 == '') && arg3 == '')) {
+                    ifConditionListStr += `)`;
+                }
          
                  if ( ifConditionList.length -1 !== index ) {
                      ifConditionListStr += '';
@@ -296,6 +307,64 @@ define([
         return ifConditionListStr;
      }
  
+      /** if param 생성 */
+    var GenerateWhileConditionList = function(thatBlock) {
+        var ifConditionList = thatBlock.getState(STATE_whileConditionList);
+ 
+
+        var ifConditionListStr = ``;
+        ifConditionList.forEach(( ifCondition, index ) => {
+            // const { conditionType } = ifCondition;
+            // if (conditionType == IF_BLOCK_CONDITION_TYPE.ARG) {
+                const { arg1, arg2, arg3, arg4, arg5, arg6 } = ifCondition;
+               //  if (arg1 == '' && arg2 == '' && arg3 == ''&& (arg4 == 'none' || arg4 == '')) {
+               //      return;
+               //  }
+               if ( !(arg1 == '' && (arg2 == 'none' || arg2 == '') && arg3 == '')) {
+                   ifConditionListStr += `(`;
+               }
+               //  ifConditionListStr += `(`;
+                ifConditionListStr += arg1;
+ 
+                if ( arg2 !== 'none' ) {
+                   ifConditionListStr += arg2;
+                }
+                ifConditionListStr += arg3;
+        
+                if ( arg4 !== 'none' ) {
+                    ifConditionListStr += arg4;
+                    ifConditionListStr += arg5;
+                }
+                
+                if ( !(arg1 == '' && (arg2 == 'none' || arg2 == '') && arg3 == '')) {
+                   ifConditionListStr += `)`;
+               }
+        
+                if ( ifConditionList.length -1 !== index ) {
+                    ifConditionListStr += '';
+                    ifConditionListStr += arg6;
+                    ifConditionListStr += '';
+                }
+            // } else {
+                // const { codeLine, arg6 } = ifCondition;
+                // if (codeLine == '') {
+                //     return;
+                // }
+                // ifConditionListStr += `(`;
+                // ifConditionListStr += codeLine;
+                // ifConditionListStr += `)`;
+
+                // if ( ifConditionList.length -1 !== index ) {
+                //     ifConditionListStr += '';
+                //     ifConditionListStr += arg6;
+                //     ifConditionListStr += '';
+                // }
+            // }
+
+        });
+
+       return ifConditionListStr;
+    }
      var GenerateExceptConditionList = function(thatBlock) {
          var exceptConditionList = thatBlock.getState(STATE_exceptConditionList);
  
@@ -304,34 +373,24 @@ define([
             const { conditionType } = exceptCondition;
             if (conditionType == IF_BLOCK_CONDITION_TYPE.ARG) {
                 const { arg1, arg2, arg3 } = exceptCondition;
-                // exceptConditionListStr += `(`;
+        
                 exceptConditionListStr += arg1;
 
                 if ( arg2 == 'none' || arg2 == STR_NULL ) {
-                    // exceptConditionListStr += arg2;
-                    // exceptConditionListStr += arg3;
                 } else {
                     exceptConditionListStr += ' ';
                     exceptConditionListStr += arg2;
                     exceptConditionListStr += ' ';
                     exceptConditionListStr += arg3;
                 }
-                
-                // exceptConditionListStr += `)`;
+        
             } else {
                 const { codeLine } = exceptCondition;
                 if (codeLine == '') {
                     return;
                 }
-                // exceptConditionListStr += `(`;
+             
                 exceptConditionListStr += codeLine;
-                // exceptConditionListStr += `)`;
-
-                // if ( ifConditionList.length -1 !== index ) {
-                //     ifConditionListStr += '';
-                //     ifConditionListStr += arg6;
-                //     ifConditionListStr += '';
-                // }
             }
      
          });
@@ -342,7 +401,7 @@ define([
      /** for param 생성 */
      var GenerateForParam = function(thatBlock) {
          var forParam = thatBlock.getState(STATE_forParam);
-         const { arg1, arg2, arg3, arg4, arg5, arg6, arg7, arg3InputStr, arg3Default } = forParam;
+         const { arg1, arg2, arg3, arg4, arg5, arg6, arg7 } = forParam;
  
          var forParamStr = ``;
  
@@ -410,16 +469,7 @@ define([
    
              forParamStr += ')';
  
-         } 
-        //  else if (arg3 == FOR_BLOCK_ARG3_TYPE.INPUT_STR) {
-        //     forParamStr += arg3InputStr;
-        //     forParamStr += '(';
-        //     forParamStr += arg2;
-        //     forParamStr += ')';
-        // } else {
-        //     forParamStr += arg3Default;
-        // }
-          else {
+         } else {
             if (arg3 != FOR_BLOCK_ARG3_TYPE.INPUT_STR) {
                 forParamStr += arg3;
             } 
@@ -689,6 +739,24 @@ define([
         return codeLine;
      };
 
+     var GenerateWhileBlockCode = function(thisBlock) {
+        var whileBlockCode = STR_NULL;
+        var whileArgsState = thisBlock.getState(STATE_whileArgs)
+        var whileBlockOptionType = thisBlock.getState(STATE_whileBlockOptionType);
+        const { arg1, arg2, arg3, arg4, arg5 } = whileArgsState;
+
+        if (whileBlockOptionType == WHILE_BLOCK_TYPE.CONDITION) {
+            whileBlockCode += arg4;
+            whileBlockCode += arg2;
+            whileBlockCode += arg3;
+        } else if (whileBlockOptionType == WHILE_BLOCK_TYPE.TRUE_FALSE) {
+            whileBlockCode += arg1;
+        } else {
+            whileBlockCode += arg1;
+        }
+        return whileBlockCode;
+     }
+
      var ShowImportListAtBlock = function(thisBlock) {
         var codeLine = STR_NULL;
         // var blockName = 'import';
@@ -713,11 +781,26 @@ define([
             codeLine += customImportList[0].baseImportName + ' as ' + customImportList[0].baseAcronyms;
         }
         return codeLine;
-     }
+    }
+    
+    /**  멀티라인의 첫번째 줄만 보여준다 */
+    var ShowCodeBlockCode = function(thisBlock) {
+        var codeLine = thisBlock.getState(STATE_customCodeLine);
+        var firstNewLine_index = codeLine.indexOf('\n');
+        if (firstNewLine_index != -1) {
+            var sliced_codeline = codeLine.slice(0, firstNewLine_index);
+            return sliced_codeline;
+        } else {
+            return codeLine;
+        }
+    }
+    
 
      /** TODO: blockCodeLine type에 따라 css를 다르게 해야 함 */
-     var RenderBlockMainHeaderDom = function(thatBlock) {
+    var RenderBlockMainHeaderDom = function(thatBlock) {
+
         var blockCodeLineType =  thatBlock.getBlockCodeLineType();
+
         /** class 이름 */
         var className = thatBlock.getState(STATE_className);
         var classInParamStr = GenerateClassInParamList(thatBlock);
@@ -730,28 +813,30 @@ define([
         /** if */ 
         var ifConditionStr = GenerateIfConditionList(thatBlock, BLOCK_CODELINE_TYPE.IF);
         var elifConditionStr = GenerateIfConditionList(thatBlock, BLOCK_CODELINE_TYPE.ELIF);
+    
         var forParamStr = GenerateForParam(thatBlock);
         var lambdaParamStr = GenerateLambdaParamList(thatBlock);
         var exceptParamStr = GenerateExceptConditionList(thatBlock);
+        var whileBlockCode = GenerateWhileConditionList(thatBlock);
         var importListStr = ShowImportListAtBlock(thatBlock);
         var blockName = thatBlock.getBlockName();
  
         /** true면 Block이 board에서 이름이 표시되지 않는다. */
-         var isBlockName = true;
-         var blockSymbol = '';
-         if ( IsCodeBlockType(blockCodeLineType) == true
-             || blockCodeLineType == BLOCK_CODELINE_TYPE.LAMBDA) {
-             isBlockName = false;
-         }
+        var isBlockName = true;
+        var blockSymbol = '';
+        if ( IsCodeBlockType(blockCodeLineType) == true 
+            || blockCodeLineType == BLOCK_CODELINE_TYPE.LAMBDA) {
+            isBlockName = false;
+        }
  
-         if (blockCodeLineType == BLOCK_CODELINE_TYPE.PROPERTY) {
-             blockSymbol = '@';
-             isBlockName = false;
-         }
-         if (blockCodeLineType == BLOCK_CODELINE_TYPE.COMMENT) {
-             blockSymbol = '#';
-             isBlockName = false;
-         }
+        if (blockCodeLineType == BLOCK_CODELINE_TYPE.PROPERTY) {
+            blockSymbol = '@';
+            isBlockName = false;
+        }
+        if (blockCodeLineType == BLOCK_CODELINE_TYPE.COMMENT) {
+            blockSymbol = '#';
+            isBlockName = false;
+        }
  
         var blockUUID = thatBlock.getUUID();
         var mainHeaderDom = $(`<div class='vp-block-header'>
@@ -861,7 +946,7 @@ define([
                                                          class='vp-block-header-param
                                                                 vp-block-header-${blockUUID}'
                                                          style='font-size:12px;'>
-                                                         ${thatBlock.getState(STATE_whileCodeLine)}
+                                                         ${whileBlockCode}
                                                      </div>`
                                                  : STR_NULL
                                          }   
@@ -881,19 +966,18 @@ define([
                                          || blockCodeLineType == BLOCK_CODELINE_TYPE.CONTINUE  
                                          || blockCodeLineType == BLOCK_CODELINE_TYPE.PASS 
                                          || blockCodeLineType == BLOCK_CODELINE_TYPE.CODE  
- 
-                                      
                                          || blockCodeLineType == BLOCK_CODELINE_TYPE.COMMENT 
+                                         || blockCodeLineType == BLOCK_CODELINE_TYPE.PRINT
                                                 ? `<div id='vp_block-${blockUUID}'
                                                          class='vp-block-header-param
                                                                 vp-block-header-${blockUUID}'
                                                         style='font-size:12px; 
-                                                               color:${thatBlock.getState(STATE_customCodeLine) == STR_NULL 
+                                                               color:${ShowCodeBlockCode(thatBlock) == STR_NULL 
                                                                              ? `${COLOR_GRAY_input_your_code}` 
                                                                              : ''};'>
-                                                        ${thatBlock.getState(STATE_customCodeLine) == STR_NULL
+                                                        ${ShowCodeBlockCode(thatBlock) == STR_NULL
                                                             ? STR_INPUT_YOUR_CODE
-                                                            : thatBlock.getState(STATE_customCodeLine)}
+                                                            : ShowCodeBlockCode(thatBlock)}
                                                     </div>`
                                                 : STR_NULL
                                         }
@@ -930,12 +1014,8 @@ define([
                                          ${
                                              blockCodeLineType == BLOCK_CODELINE_TYPE.BLANK        
                                                  ? `<div id='vp_block-${blockUUID}'
-                                                         class='vp-block-header-param
-                                                                vp-block-header-${blockUUID}'
-                                                         style='font-size:12px;
-                                                                text-align:center;
-                                                                color:${COLOR_GRAY_input_your_code}'>
-                                                         blank code line
+                                                         style='background-color:transparent;'>
+                                                      
                                                      </div>`
                                                  : STR_NULL
                                          }    
@@ -953,44 +1033,7 @@ define([
                                 </div>`);
          mainHeaderDom.attr("id", `vp_block-${blockUUID}`);
         return mainHeaderDom;
-    }
- 
-    var RenderOptionPageContainer = function() {
-        return $(`<div class='vp-apiblock-style-flex-row-center' 
-                       style='padding: 0.5rem;'></div>`);
-    }
- 
-    var RenderOptionPageContainerInner = function() {
-        return $(`<div class='vp-apiblock-blockoption 
-                            vp-apiblock-option'
-                       style='width: 95%;'>
-                  </div>`);
-    }
- 
-    var RenderDomContainer = function() {
-        var domContainer = $(`<div class='vp-apiblock-option-container'>
-                                    <div class='vp-apiblock-tab-navigation-node-block-title'>
-                                        <span class='vp-block-optiontab-name'>code</span>
-                                        <div class='vp-apiblock-style-flex-row-center'>
-                                            <div class='vp-apiblock-option-vertical-btn'>▼</div>
-                                        </div>
-                                    </div>
-                              </div>`);
-        return domContainer;
-    }
- 
-    var RenderOptionPageInnerDom = function() {
-        var innerDom = $(`<div class='vp-apiblock-option-container'>
-                                <div class='vp-apiblock-tab-navigation-node-block-title'>
-                                    
-                                </div>
-                            </div>`);
- 
-        return innerDom;
-    }
-
- 
-  
+    }  
  
     var RenderOptionPageName = function(thatBlock, name, blockCodeLineType, uuid) {
          var classStr = STR_NULL;
@@ -1025,75 +1068,15 @@ define([
                 classStr += VP_CLASS_APIBLOCK_OPTION_INPUT_REQUIRED;
              }
  
-         } else if (blockCodeLineType == BLOCK_CODELINE_TYPE.WHILE) {
-            idStr = `vp_apiblockwhileOptionInput${uuid}`;
-            classStr = `vp-apiblock-while-input-${uuid}`;
-            inputStyleStr = 'width:80%;';
-            /** state whileCodeLine에 문자열이 1개도 없을 때 */
-            var whileCodeLineState = thatBlock.getState(STATE_whileCodeLine);
-            if (whileCodeLineState == STR_NULL) {
-                classStr += STR_ONE_SPACE;
-                classStr += VP_CLASS_APIBLOCK_OPTION_INPUT_REQUIRED;
-            }
- 
-         } else if (blockCodeLineType == BLOCK_CODELINE_TYPE.CODE
-                   || blockCodeLineType == BLOCK_CODELINE_TYPE.COMMENT
-                   || blockCodeLineType == BLOCK_CODELINE_TYPE.BREAK
-                   || blockCodeLineType == BLOCK_CODELINE_TYPE.CONTINUE
-                   || blockCodeLineType == BLOCK_CODELINE_TYPE.PASS
-                   || blockCodeLineType == BLOCK_CODELINE_TYPE.PROPERTY) {
-             idStr = `vp_apiblockCodeOptionInput${uuid}`;
-             inputStyleStr = 'width:80%;';
-             /** state codeline에 문자열이 1개도 없을 때 */
-             var codeLineState = thatBlock.getState(STATE_customCodeLine);
-             if (codeLineState == STR_NULL) {
-                classStr += STR_ONE_SPACE;
-                classStr += VP_CLASS_APIBLOCK_OPTION_INPUT_REQUIRED;
-             }
-             resetButton = $(`<button class='vp-apiblock-option-reset-button 
-                                            vp-block-btn'>Reset</button>`);
-             $(resetButton).click(function() {
-                 var blockCodeLineType = thatBlock.getBlockCodeLineType();
-                 var defaultStr = STR_NULL;
-                 var resetColor = '#d4d4d4';
-                if (blockCodeLineType == BLOCK_CODELINE_TYPE.BREAK) {
-                     defaultStr = STR_BREAK;
-                     resetColor = 'black';
-                } else if (blockCodeLineType == BLOCK_CODELINE_TYPE.CONTINUE) {
-                     defaultStr = STR_CONTINUE;
-                     resetColor = 'black';
-                } else if (blockCodeLineType == BLOCK_CODELINE_TYPE.PASS) {
-                     defaultStr = STR_PASS;
-                     resetColor = 'black';
-                } else {
- 
-                }
-                thatBlock.setState({
-                    customCodeLine: defaultStr
-                });
-                $(`#vp_apiblockCodeOptionInput${uuid}`).html(defaultStr);
-                $(`.vp-block-header-${thatBlock.getUUID()}`).html(defaultStr || STR_INPUT_YOUR_CODE);
-                $(`.vp-block-header-${thatBlock.getUUID()}`).css('color', resetColor);
-                blockContainerThis.renderBlockOptionTab();
-                blockContainerThis.bindCodeBlockInputFocus(thatBlock);
-            });
          } 
         
          var nameDom = $(`<div class='vp-apiblock-blockoption-block 
                                       vp-apiblock-style-flex-row-between' 
                                 style='position:relative;'>
-                            ${
-                                blockCodeLineType == BLOCK_CODELINE_TYPE.IF 
-                                || blockCodeLineType == BLOCK_CODELINE_TYPE.FOR
-                                || blockCodeLineType == BLOCK_CODELINE_TYPE.WHILE 
-                                || blockCodeLineType == BLOCK_CODELINE_TYPE.DEF
-                                || blockCodeLineType == BLOCK_CODELINE_TYPE.CLASS
-                                    ?  `<span class='vp-block-optiontab-name 
-                                                     vp-apiblock-style-flex-column-center'>
-                                                     ${blockCodeName}
-                                        </span>`
-                                    : ''
-                            }
+                            <span class='vp-block-optiontab-name 
+                                         vp-apiblock-style-flex-column-center'>
+                                ${blockCodeName}
+                            </span>
                             <input id='${idStr}'
                                    class='vp-apiblock-blockoption-input ${classStr}'
                                    style='${inputStyleStr}' 
@@ -1123,45 +1106,6 @@ define([
                                         </div>`);
         return inParamContainer;
     }
-    
- 
- 
-     /** 인자 순서 조절 */
-     var RenderInParamDom = function(inParam, index, blockCodeLineType, block) {
-        var classStr = STR_NULL;
-        var uuid = block.getUUID();
-        if (blockCodeLineType == BLOCK_CODELINE_TYPE.CLASS) {
-            classStr = `vp-apiblock-input-param-${index}-${uuid}`;
-        } else if (blockCodeLineType == BLOCK_CODELINE_TYPE.DEF) {
-            classStr = `vp-apiblock-input-param-${index}-${uuid}'`;
-        } else if (blockCodeLineType == BLOCK_CODELINE_TYPE.RETURN ) {
-            classStr = `vp-apiblock-input-param-${index}-${uuid}`;
-        } else if (blockCodeLineType == BLOCK_CODELINE_TYPE.EXCEPT) {
-            classStr = `vp-apiblock-except-input-${uuid}`;
-        } else if (blockCodeLineType == BLOCK_CODELINE_TYPE.ELIF) {
-            classStr = `vp-apiblock-elif-input-${uuid}`;
-        }
- 
-        var inParamDom = $(`<div class='vp-apiblock-style-flex-row-between'
-                                 style='margin-top:5px;'>
- 
-                                <div class='vp-apiblock-style-flex-column-center'
-                                    style='margin:0 0.5rem; color: rgba(0,0,0,0.3);'>
-                                    ${index+1}
-                                </div>
- 
-                                <div class='vp-apiblock-blockoption-block
-                                            vp-apiblock-blockoption-inner 
-                                            vp-apiblock-style-flex-row' 
-                                     style='position:relative; 
-                                            width:85%;'>
-                                    <input placeholder='input param' 
-                                           class='vp-apiblock-blockoption-input ${classStr}' 
-                                           value='${inParam}'>                                                        
-                                </div>
-                            </div>`);
-        return inParamDom;
-    }
  
     var RenderBottomOptionTitle = function(title) {
         var titleDom = $(`<div class='vp-apiblock-option-container'
@@ -1223,28 +1167,15 @@ define([
     }
  
     var RenderSelectRequiredColor = function(target, selectedValue) {
-     if (selectedValue == STR_NULL) {
-         // $(thatBlock).css(STR_FONT_WEIGHT, NUM_FONT_WEIGHT_300);
-         $(target).addClass(VP_CLASS_APIBLOCK_OPTION_INPUT_REQUIRED)
-     } else {
-         // $(thatBlock).css(STR_FONT_WEIGHT, NUM_FONT_WEIGHT_700);
-         $(target).removeClass(VP_CLASS_APIBLOCK_OPTION_INPUT_REQUIRED); 
-     }
- }
-    var RenderDeleteButton = function() {
-        return $(`<button class='vp-block-btn'>
-                    x
-                    </button>`);
-    }
- 
-    var RenderSmallPlusDeleteButton = function(plusMinusStr) {
-        var button = $(`<div class='vp-apiblock-style-flex-column-center'>
-                            <button class='vp-apiblock-option-condition-button'>
-                                ${plusMinusStr} 
-                            </button>
-                        </div>`);
-        return button;
+        if (selectedValue == STR_NULL) {
+            // $(thatBlock).css(STR_FONT_WEIGHT, NUM_FONT_WEIGHT_300);
+            $(target).addClass(VP_CLASS_APIBLOCK_OPTION_INPUT_REQUIRED)
+        } else {
+            // $(thatBlock).css(STR_FONT_WEIGHT, NUM_FONT_WEIGHT_700);
+            $(target).removeClass(VP_CLASS_APIBLOCK_OPTION_INPUT_REQUIRED); 
+        }
     }
+
  
     var RenderCustomImportDom = function(customImportData, index) {
         const { isImport, baseImportName, baseAcronyms } = customImportData;
@@ -1346,80 +1277,6 @@ define([
         return container;
     }
  
-    var RenderIfElifOrExceptContainer = function(blockCodeLineType) {
-        var name = STR_NULL;
-        var blockName = STR_NULL;
-     
-        if ( blockCodeLineType == BLOCK_CODELINE_TYPE.IF ) {
-            name = 'con';
-            blockName = 'if';
-  
-        } else if ( blockCodeLineType == BLOCK_CODELINE_TYPE.ELIF ) {
-            name = 'elif';
-            blockName = 'elif';
- 
-        } else {
-            name = 'except';
-            blockName = 'except';
-        }
- 
-  
-        var container = $(`<div class='vp-apiblock-option-container'
-                                style='margin-top:5px;'>
-                                <div class='vp-apiblock-tab-navigation-node-block-title'>
-                                    <span class='vp-block-optiontab-name'>
-                                    ${blockName}
-                                    </span>
-                                       
-                                </div>
-                            </div>`);
-        return container;
-    }
- 
-    var RenderDefParamOrIfElifConditionPlusButton = function(blockCodeLineType, block) {
-        var name = STR_NULL;
-        var classStr = STR_NULL;
-        var styleStr = STR_NULL;
- 
-        if ( blockCodeLineType == BLOCK_CODELINE_TYPE.IF ) {
-            name = 'condition';
-            classStr = 'vp-apiblock-if-plus-btn';
-            styleStr = 'margin-left: 0.5rem;';
-        } else if ( blockCodeLineType == BLOCK_CODELINE_TYPE.ELIF ) {
-            name = 'elif';
-            classStr = `vp-apiblock-elif-plus-btn-${block.getUUID()}`;
-            styleStr = 'margin-left: 0.5rem;';
-        } else if ( blockCodeLineType == BLOCK_CODELINE_TYPE.FOR ) {
-            name = 'list for';
-            classStr = `vp-apiblock-listfor-plus-btn-${block.getUUID()}`;
-            styleStr = 'margin-left: 0.5rem;';
-        } else if ( blockCodeLineType == BLOCK_CODELINE_TYPE.DEF ) {
-            name = 'param';
-            classStr = `${VP_CLASS_APIBLOCK_PARAM_PLUS_BTN}-${block.getUUID()}`;
-            styleStr = 'margin-left: 0.5rem;';
-        } else if ( blockCodeLineType == BLOCK_CODELINE_TYPE.RETURN ) {
-            name = 'param';
-            classStr = `${VP_CLASS_APIBLOCK_PARAM_PLUS_BTN}-${block.getUUID()}`;
-            styleStr = 'margin-left: 0.5rem;';
-        }  else {
-            name = 'except';
-            classStr = `vp_apiblockExceptPlusBtn${block.getUUID()}`;
-            styleStr = 'margin-left: 0.5rem;';
-        }
- 
-        var plusButton = $(`<div class='vp-apiblock-style-flex-row-center' >         
-                                <button class='vp-block-long-plus-button
-                                               ${classStr}'
-                                        style='margin-right: 5px;
-                                               width: 100%;
-                                               margin-top: 5px;
-                                               ${styleStr}'>
-                                    + ${name}
-                                </button>       
-                            </div>`);
-        return plusButton;                         
-    }
- 
     var RenderDefaultImportDom = function(baseImportData, index) {
         const { isImport, baseImportName, baseAcronyms } = baseImportData;
         var defaultImportDom = $(`<div class='vp-apiblock-style-flex-row-between'
@@ -1474,7 +1331,9 @@ define([
  
         $(vpCommon.wrapSelector(VP_CLASS_PREFIX + VP_CLASS_APIBLOCK_BOARD)).css(STR_BORDER, STR_TRANSPARENT);
         $(vpCommon.wrapSelector(VP_CLASS_PREFIX + VP_CLASS_APIBLOCK_BOARD)).css(STR_BORDER_RIGHT, `1px ${STR_SOLID} #d4d4d4`);
- 
+        $(vpCommon.wrapSelector(VP_CLASS_PREFIX + VP_CLASS_APIBLOCK_BOARD)).css(STR_BORDER_TOP_RIGHT_RADIUS, '7px');
+        $(vpCommon.wrapSelector(VP_CLASS_PREFIX + VP_CLASS_APIBLOCK_BOARD)).css(STR_BORDER_BOTTOM_RIGHT_RADIUS, '7px');
+
         $(vpCommon.wrapSelector(VP_CLASS_PREFIX + VP_CLASS_APIBLOCK_OPTION_TAB)).css(STR_BORDER, STR_TRANSPARENT);
         $(vpCommon.wrapSelector(VP_CLASS_PREFIX + VP_CLASS_APIBLOCK_OPTION_TAB)).css(STR_BORDER_TOP_RIGHT_RADIUS, '7px');
         $(vpCommon.wrapSelector(VP_CLASS_PREFIX + VP_CLASS_APIBLOCK_OPTION_TAB)).css(STR_BORDER_BOTTOM_RIGHT_RADIUS, '7px');
@@ -1640,7 +1499,6 @@ define([
  
          } else if (blockCodeLineType == BLOCK_CODELINE_TYPE.BLANK){
              $(htmlDom).css('background-color', 'transparent !important');
-             $(htmlDom).css('border', '1px solid rgb(229, 229, 229)');
     
          } else if (blockCodeLineType == BLOCK_CODELINE_TYPE.HOLDER ) {
 
@@ -1650,102 +1508,6 @@ define([
          return htmlDom;
      }
  
-    //  var RenderOptionPagePlusBtn = function(uuid, string) {
-    //      var sbPlusMinusConditionBtn = new sb.StringBuilder();
- 
-    //      /** plus button */
-    //      sbPlusMinusConditionBtn.appendFormatLine("<div class='{0}'>", 'vp-apiblock-style-flex-row-center');
-    //      sbPlusMinusConditionBtn.appendFormatLine("<button class='{0} {1}'>" , 'vp-block-long-plus-button'
-    //                                                                          , `vp-apiblock-plus-button-${uuid}`);
-    //      sbPlusMinusConditionBtn.appendFormatLine("{0}", string ||'+ Click to add');                                                    
-    //      sbPlusMinusConditionBtn.appendLine("</button>"); 
-    //      sbPlusMinusConditionBtn.appendLine("</div>");
- 
-    //      return sbPlusMinusConditionBtn.toString();
-    //  }
- 
-    //  var RenderOptionPageDeleteBtn_type1 = function(uuid, string) {
-    //      var sbPlusMinusConditionBtn = new sb.StringBuilder();
- 
-    //      /** plus button */
-    //      sbPlusMinusConditionBtn.appendFormatLine("<div class='{0}'>", 'vp-apiblock-style-flex-row-center');
-    //      sbPlusMinusConditionBtn.appendFormatLine("<button class='{0} {1}'>" , 'vp-block-long-plus-button'
-    //                                                                          , `vp-apiblock-delete-button-${uuid}`);
-    //      sbPlusMinusConditionBtn.appendFormatLine("{0}", string || '- Click to minus');                                                    
-    //      sbPlusMinusConditionBtn.appendLine("</button>"); 
-    //      sbPlusMinusConditionBtn.appendLine("</div>");
- 
-    //      return sbPlusMinusConditionBtn.toString();
-    //  }
- 
-    //  var RenderOptionPageDeleteBtn = function(index, uuid) {
-    //      var sbPlusMinusConditionBtn = new sb.StringBuilder();
-    //      /** delete button */
-    //      sbPlusMinusConditionBtn.appendFormatLine("<div class='{0}'>", 'vp-apiblock-style-flex-column-center');
-    //      sbPlusMinusConditionBtn.appendFormatLine("<button class='{0} {1}'>" , 'vp-apiblock-option-condition-button'
-    //                                                                          , `vp-apiblock-delete-button-${index}-${uuid}`);
-    //      sbPlusMinusConditionBtn.appendFormatLine("{0}", 'x');                                                    
-    //      sbPlusMinusConditionBtn.appendLine("</button>"); 
-    //      sbPlusMinusConditionBtn.appendLine("</div>");
- 
-    //      sbPlusMinusConditionBtn.appendLine("</div>");
-    //      return sbPlusMinusConditionBtn.toString()
-    //  }
-    //  /**
-    //   * if, listfor, elif 의 조건 절을 생성 삭제하는 버튼을 생성
-    //   * @param {number} index 
-    //   * @param {string} uuid 
-    //   */
-    //  var RenderPlusMinusConditionBtn = function(index, uuid) {
-    //      var sbPlusMinusConditionBtn = new sb.StringBuilder();
-    //      sbPlusMinusConditionBtn.appendFormatLine("<div style='{0}'>", 'display: flex;');
- 
-    //      /** plus button */
-    //      sbPlusMinusConditionBtn.appendFormatLine("<div class='{0}'>", 'vp-apiblock-style-flex-column-center');
-    //      sbPlusMinusConditionBtn.appendFormatLine("<button class='{0} {1}'>" , 'vp-apiblock-option-condition-button'
-    //                                                                          , `vp-apiblock-plus-button-${index}-${uuid}`);
-    //      sbPlusMinusConditionBtn.appendFormatLine("{0}", '+');                                                    
-    //      sbPlusMinusConditionBtn.appendLine("</button>"); 
-    //      sbPlusMinusConditionBtn.appendLine("</div>");
- 
-    //      /** minus button */
-    //      sbPlusMinusConditionBtn.appendFormatLine("<div class='{0}'>", 'vp-apiblock-style-flex-column-center');
-    //      sbPlusMinusConditionBtn.appendFormatLine("<button class='{0} {1}'>" , 'vp-apiblock-option-condition-button'
-    //                                                                          , `vp-apiblock-delete-button-${index}-${uuid}`);
-    //      sbPlusMinusConditionBtn.appendFormatLine("{0}", '-');                                                    
-    //      sbPlusMinusConditionBtn.appendLine("</button>"); 
-    //      sbPlusMinusConditionBtn.appendLine("</div>");
- 
-    //      sbPlusMinusConditionBtn.appendLine("</div>");
- 
-    //      return sbPlusMinusConditionBtn.toString();
-    //  }
-     
-    //  var RenderOptionChildTab = function(blockNameFirstCharUpper) {
-    //      var childOptionTab = $(`<div class='vp-apiblock-tab-navigation-node-block
-    //                                      vp-apiblock-option-tab-childs-option'>
-    //                                  <div class='vp-apiblock-tab-navigation-node-childs-top-option-title
-    //                                              vp-accordion-header'
-    //                                      style='justify-content: flex-start;'>
-    //                                      <div class='vp-apiblock-panel-area-vertical-btn 
-    //                                                  vp-apiblock-arrow-up'>▼</div>
-    //                                      <span class='vp-block-blocktab-name 
-    //                                                      vp-block-blocktab-name-title
-    //                                                      vp-accordion-caption'
-    //                                              style="font-size: 16px;">
-    //                                          ${blockNameFirstCharUpper} Child Options
-    //                                      </span>
-                                         
-    //                                  </div>
- 
-    //                                  <div class="vp-apiblock-bottom-optional-tab-view 
-    //                                              vp-apiblock-scrollbar">
- 
-    //                                  </div>
-    //                              </div>`);
-    //      return childOptionTab;
-    //  }
- 
      /** FIXME: 추후 제거
       * buttons와 option page의 arrow 조작
       */
@@ -1773,25 +1535,16 @@ define([
         , RenderBlockMainHeaderDom
         , RenderDefaultImportDom
         , RenderCustomImportDom 
- 
-        , RenderOptionPageContainer
-        , RenderOptionPageContainerInner
+
         , RenderDefaultOrCustomImportContainer
-        , RenderIfElifOrExceptContainer
-        , RenderDefParamOrIfElifConditionPlusButton
+
         , RenderInParamContainer
-   
-        , RenderInParamDom
- 
-        , RenderOptionPageInnerDom
+     
         , RenderOptionPageName
-        , RenderDomContainer
-      
+
         , RenderBottomOptionTitle
  
         , RenderDefaultOrDetailButton
-        , RenderSmallPlusDeleteButton
-        , RenderDeleteButton
  
         , RenderRunBlockButton
         , RenderDeleteBlockButton
@@ -1806,13 +1559,6 @@ define([
      
         , RenderCodeBlockInputRequired
         
- 
-        // , RenderOptionPagePlusBtn
-        // , RenderOptionPageDeleteBtn_type1
-        // , RenderOptionPageDeleteBtn
-        
-        // , RenderOptionChildTab
-        
         , RenderHTMLDomColor
  
         , GenerateClassInParamList
@@ -1824,8 +1570,11 @@ define([
         , GenerateListforConditionList
         , GenerateLambdaParamList
         , GenerateImportList
+        , GenerateWhileBlockCode
+        , GenerateWhileConditionList
 
         , ShowImportListAtBlock
+        , ShowCodeBlockCode
 
         , BindArrowBtnEvent
     }
