@@ -39,53 +39,7 @@ define([
 
     const { PROCESS_MODE } = config;
 
-    const { RenderBlockMainDom
-            , RenderBlockLeftHolderDom
-            , RenderBlockMainInnerDom
-            , RenderBlockMainHeaderDom
-
-            , RenderOptionPageContainer
-            , RenderOptionPageContainerInner
-            , RenderOptionPageInnerDom
-            , RenderOptionPageName
-            , RenderOptionTitle
-
-            , RenderInParamContainer
-            , RenderInParamDom
-            , RenderDefParamDom
-            , RenderBottomOptionTitle
-            , RenderDefaultOrDetailButton
-            , RenderInputRequiredColor
-            , RenderSelectRequiredColor
-            , RenderDeleteButton
-            , RenderSmallPlusDeleteButton
-
-
-
-            , RenderDefaultImportDom
-            , RenderCustomImportDom
-            , RenderIfElifOrExceptContainer
-            , RenderDefParamOrIfElifConditionPlusButton
-            , RenderDefaultOrCustomImportContainer
-
-            , RenderRunBlockButton
-            , RenderDeleteBlockButton
-            , RenderFocusedPage
-            
-            , RenderDomContainer
-            , RenderPropertyDom
-
-
-            , RenderClassParentDom
-            , RenderCodeBlockInputRequired
-
-            , RenderHTMLDomColor
-
-            , GenerateClassInParamList
-            , GenerateDefInParamList
-            , GenerateReturnOutParamList
-            , GenerateExceptConditionList
-            , GenerateForParam } = blockRenderer;
+    const {  GenerateExceptConditionList } = blockRenderer;
 
     const { BLOCK_DIRECTION
             , BLOCK_CODELINE_BTN_TYPE
@@ -212,32 +166,6 @@ define([
                                     }
                                     // RenderInputRequiredColor(this);
                                 }  
-                                // else if (i == 4) {
-                                //     updatedValue = {
-                                //         ...ifConditionState
-                                //         ,arg4: inputValue
-                                //     }
-                                //     if (inputValue == 'none' || inputValue == STR_NULL) {
-                                //         $(VP_ID_PREFIX + VP_ID_APIBLOCK_OPTION_IF_ARG_4 + index + uuid).addClass(VP_CLASS_STYLE_BGCOLOR_C4C4C4);
-                                //         $(VP_ID_PREFIX + VP_ID_APIBLOCK_OPTION_IF_ARG_5 + index + uuid).addClass(VP_CLASS_STYLE_BGCOLOR_C4C4C4);
-                                //         $(VP_ID_PREFIX + VP_ID_APIBLOCK_OPTION_IF_ARG_5 + index + uuid).attr(STR_DISABLED, true);
-                                //     } else {
-                                //         $(VP_ID_PREFIX + VP_ID_APIBLOCK_OPTION_IF_ARG_4 + index + uuid).removeClass(VP_CLASS_STYLE_BGCOLOR_C4C4C4);
-                                //         $(VP_ID_PREFIX + VP_ID_APIBLOCK_OPTION_IF_ARG_5 + index + uuid).removeClass(VP_CLASS_STYLE_BGCOLOR_C4C4C4);
-                                //         $(VP_ID_PREFIX + VP_ID_APIBLOCK_OPTION_IF_ARG_5 + index + uuid).attr(STR_DISABLED, false);
-                                //     }
-                                // } else if (i == 5) {
-                                //     updatedValue = {
-                                //         ...ifConditionState
-                                //         , arg5: inputValue 
-                                //     }
-                                // } else {
-                                //     updatedValue = {
-                                //         ...ifConditionState
-                                //         , arg6: inputValue
-                                //     }
-                                //     RenderInputRequiredColor(this);
-                                // }
     
                                 ifConditionListState = UpdateOneArrayValueAndGet(ifConditionListState, index, updatedValue);
                                 thatBlock.setState({
@@ -278,31 +206,6 @@ define([
                 
                     event.stopPropagation();
                 });
-
-
-                // $(document).off(STR_CHANGE_KEYUP_PASTE, VP_ID_PREFIX + VP_ID_APIBLOCK_OPTION_IF_ARG_6 + index + uuid);
-                // $(document).on(STR_CHANGE_KEYUP_PASTE, VP_ID_PREFIX + VP_ID_APIBLOCK_OPTION_IF_ARG_6 + index + uuid, function(event) {
-         
-                //     RenderInputRequiredColor(this);
-           
-                //     var ifConditionListState = thatBlock.getState(STATE_exceptConditionList);
-                //     var ifConditionState = ifConditionListState[index];
-                //     var inputValue = $(this).val();
-
-                //     var updatedValue = {
-                //         ...ifConditionState
-                //         , arg6: inputValue
-                //     }
-
-                //     ifConditionListState = UpdateOneArrayValueAndGet(ifConditionListState, index, updatedValue);
-                //     thatBlock.setState({
-                //         [STATE_exceptConditionList]: ifConditionListState
-                //     });
-                //     var ifConditionCode = GenerateExceptConditionList(thatBlock,BLOCK_CODELINE_TYPE.ELIF);
-                //     $(`.vp-block-header-${thatBlock.getUUID()}`).html(ifConditionCode);
-                
-                //     event.stopPropagation();
-                // });
             }
                    
             /** 삭제 if condition */
@@ -413,35 +316,6 @@ define([
                 // RenderSelectRequiredColor(VP_ID_PREFIX + VP_ID_APIBLOCK_OPTION_IF_ARG_3 + index + uuid, selectedValue);
             } 
 
-  
-            // else if (type == IF_BLOCK_SELECT_VALUE_ARG_TYPE.ARG4) {
-            //     updatedValue = {
-            //         ...ifConditionState
-            //         , arg4: selectedValue 
-            //     }
-
-            //     if (selectedValue == 'none' || selectedValue == '') {
-            //         $(VP_ID_PREFIX + VP_ID_APIBLOCK_OPTION_IF_ARG_4 + index + uuid).addClass(VP_CLASS_STYLE_BGCOLOR_C4C4C4);
-            //         $(VP_ID_PREFIX + VP_ID_APIBLOCK_OPTION_IF_ARG_5 + index + uuid).addClass(VP_CLASS_STYLE_BGCOLOR_C4C4C4);
-            //         $(VP_ID_PREFIX + VP_ID_APIBLOCK_OPTION_IF_ARG_5 + index + uuid).attr(STR_DISABLED, true);
-            //     } else {
-            //         $(VP_ID_PREFIX + VP_ID_APIBLOCK_OPTION_IF_ARG_4 + index + uuid).removeClass(VP_CLASS_STYLE_BGCOLOR_C4C4C4);
-            //         $(VP_ID_PREFIX + VP_ID_APIBLOCK_OPTION_IF_ARG_5 + index + uuid).removeClass(VP_CLASS_STYLE_BGCOLOR_C4C4C4);
-            //         $(VP_ID_PREFIX + VP_ID_APIBLOCK_OPTION_IF_ARG_5 + index + uuid).attr(STR_DISABLED, false);
-            //     }
-
-            // } else if (type == IF_BLOCK_SELECT_VALUE_ARG_TYPE.ARG5) {
-            //     updatedValue = {
-            //         ...ifConditionState
-            //         , arg5: selectedValue 
-            //     }
-            // } else {
-            //     updatedValue = {
-            //         ...ifConditionState
-            //         , arg6: selectedValue 
-            //     }
-            //     RenderSelectRequiredColor(VP_ID_PREFIX + VP_ID_APIBLOCK_OPTION_IF_ARG_6 + index + uuid, selectedValue);
-            // }
             ifConditionListState = UpdateOneArrayValueAndGet(ifConditionListState, index, updatedValue);
             thatBlock.setState({
                 [STATE_exceptConditionList]: ifConditionListState
@@ -454,8 +328,7 @@ define([
         }
 
         /** --------------------------------- Else Option 이벤트 함수 바인딩 ---------------------------------- */  
-        /** Else block 생성, 삭제 이벤트 함수 바인딩 */
-        // blockContainerThis.bindElseBlockEvent(thatBlock, BLOCK_CODELINE_TYPE.ELSE);
+
 
 
 
@@ -526,37 +399,7 @@ define([
                                                                                                             index,
                                                                                                             IF_BLOCK_SELECT_VALUE_ARG_TYPE.ARG3);
                                                                                 });   
-                    // var suggestInputArg4 =  MakeVpSuggestInputText_apiblock(VP_ID_APIBLOCK_OPTION_IF_ARG_4 + index + uuid
-                    //                                                         , arg4
-                    //                                                         , COMPARISON_OPERATOR_IF_ARG4
-                    //                                                         , VP_CLASS_STYLE_WIDTH_15PERCENT
-                    //                                                         , STR_OPERATOR
-                    //                                                         , function(selectedValue) {
-                    //                                                             bindSelectValueEventFunc_if(selectedValue, 
-                    //                                                                 index,
-                    //                                                                 IF_BLOCK_SELECT_VALUE_ARG_TYPE.ARG4);
-                    //                                                         });    
-                    // var suggestInputArg5 =  MakeVpSuggestInputText_apiblock(VP_ID_APIBLOCK_OPTION_IF_ARG_5 + index + uuid
-                    //                                                         , arg5
-                    //                                                         , loadedVariableNameList_arg5
-                    //                                                         , VP_CLASS_STYLE_WIDTH_20PERCENT
-                    //                                                         , STR_VARIABLE
-                    //                                                         , function(selectedValue) {
-                    //                                                             bindSelectValueEventFunc_if(selectedValue, 
-                    //                                                                                         index,
-                    //                                                                                         IF_BLOCK_SELECT_VALUE_ARG_TYPE.ARG5);
-                    //                                                             });    
-
-                    // var suggestInputArg6 =  MakeVpSuggestInputText_apiblock(VP_ID_APIBLOCK_OPTION_IF_ARG_6 + index + uuid
-                    //                                                             , arg6
-                    //                                                             , COMPARISON_OPERATOR_IF_ARG6
-                    //                                                             , VP_CLASS_STYLE_WIDTH_10PERCENT
-                    //                                                             , STR_OPERATOR
-                    //                                                             , function(selectedValue) {
-                    //                                                                 bindSelectValueEventFunc_if(selectedValue, 
-                    //                                                                     index,
-                    //                                                                     IF_BLOCK_SELECT_VALUE_ARG_TYPE.ARG6);
-                    //                                                         });      
+    
                     sbConditionLeft.appendLine(suggestInputArg1);
                     sbConditionLeft.appendLine(suggestInputArg2);
                     sbConditionLeft.appendLine(suggestInputArg3);
@@ -579,21 +422,8 @@ define([
                                                         , 'Type user code');
                     sbConditionLeft.appendLine(sbOptionInput);
                     sbConditionLeft.appendLine("</div>");
-                    // var suggestInputArg6 =  MakeVpSuggestInputText_apiblock(VP_ID_APIBLOCK_OPTION_IF_ARG_6 + index + uuid
-                    //                                         , arg6
-                    //                                         , COMPARISON_OPERATOR_IF_ARG6
-                    //                                         , VP_CLASS_STYLE_WIDTH_10PERCENT
-                    //                                         , STR_OPERATOR
-                    //                                         , function(selectedValue) {
-                    //                                             bindSelectValueEventFunc_if(selectedValue, 
-                    //                                                 index,
-                    //                                                 IF_BLOCK_SELECT_VALUE_ARG_TYPE.ARG6);
-                    //                                     });    
-                    sbCondition.appendLine(sbConditionLeft.toString());
-                    // sbCondition.appendLine(suggestInputArg6);
 
-                    // var deleteConditionButton = MakeOptionDeleteButton(VP_ID_APIBLOCK_OPTION_IF_DELETE + index + uuid);
-                    // sbCondition.appendLine(deleteConditionButton);
+                    sbCondition.appendLine(sbConditionLeft.toString());
 
                     sbCondition.appendLine("</div>");
                 }
@@ -601,7 +431,6 @@ define([
                 var tblLayout = new vpTableLayoutVerticalSimple.vpTableLayoutVerticalSimple();
                 tblLayout.setTHWidth("5%");
                 tblLayout.addClass(VP_CLASS_STYLE_WIDTH_100PERCENT);
-                // tblLayout.addRow(index + 1, sbCondition.toString());
                 tblLayout.addRow('', sbCondition.toString());
  
                 optionContainerDom.append(tblLayout.toTagString());              
@@ -636,10 +465,7 @@ define([
                 $(VP_ID_PREFIX + VP_ID_APIBLOCK_OPTION_IF_ARG_1 + index + uuid).val(arg1);
                 $(VP_ID_PREFIX + VP_ID_APIBLOCK_OPTION_IF_ARG_2 + index + uuid).val(arg2);
                 $(VP_ID_PREFIX + VP_ID_APIBLOCK_OPTION_IF_ARG_3 + index + uuid).val(arg3);
-                // $(VP_ID_PREFIX + VP_ID_APIBLOCK_OPTION_IF_ARG_4 + index + uuid).val(arg4);
-                // $(VP_ID_PREFIX + VP_ID_APIBLOCK_OPTION_IF_ARG_5 + index + uuid).val(arg5);
-                // var isArg5Disabled = false;   
-                // isArg5Disabled = true;
+   
                 if (arg2 == 'none' || arg2 == STR_NULL) {
                     $(VP_ID_PREFIX + VP_ID_APIBLOCK_OPTION_IF_ARG_2 + index + uuid).addClass(VP_CLASS_STYLE_BGCOLOR_C4C4C4);
                     $(VP_ID_PREFIX + VP_ID_APIBLOCK_OPTION_IF_ARG_3 + index + uuid).attr(STR_DISABLED, true);
@@ -651,25 +477,7 @@ define([
                     $(VP_ID_PREFIX + VP_ID_APIBLOCK_OPTION_IF_ARG_3 + index + uuid).removeClass(VP_CLASS_STYLE_BGCOLOR_C4C4C4);
                 } 
   
-                // if (arg4 == 'none' || arg4 == STR_NULL) {
-                //     $(VP_ID_PREFIX + VP_ID_APIBLOCK_OPTION_IF_ARG_4 + index + uuid).addClass(VP_CLASS_STYLE_BGCOLOR_C4C4C4);
-                //     $(VP_ID_PREFIX + VP_ID_APIBLOCK_OPTION_IF_ARG_5 + index + uuid).attr(STR_DISABLED, true);
-                //     $(VP_ID_PREFIX + VP_ID_APIBLOCK_OPTION_IF_ARG_5 + index + uuid).addClass(VP_CLASS_STYLE_BGCOLOR_C4C4C4);
-                // } else {
-                //     $(VP_ID_PREFIX + VP_ID_APIBLOCK_OPTION_IF_ARG_4 + index + uuid).removeClass(VP_CLASS_STYLE_BGCOLOR_C4C4C4);
-                //     $(VP_ID_PREFIX + VP_ID_APIBLOCK_OPTION_IF_ARG_5 + index + uuid).attr(STR_DISABLED, false);
-                //     $(VP_ID_PREFIX + VP_ID_APIBLOCK_OPTION_IF_ARG_5 + index + uuid).removeClass(VP_CLASS_STYLE_BGCOLOR_C4C4C4);
-                // }     
 
-                /** arg6 isDisabled 체크 */
-                // var isArg6Disabled = false;
-                // isArg6Disabled = true;
-                // if ( ifConditionListState.length -1 == index ) {
-                //     $(VP_ID_PREFIX + VP_ID_APIBLOCK_OPTION_IF_ARG_6 + index + uuid).addClass(VP_CLASS_STYLE_OPACITY_0);
-                // } else {
-                //     $(VP_ID_PREFIX + VP_ID_APIBLOCK_OPTION_IF_ARG_6 + index + uuid).val(arg6);
-                //     $(VP_ID_PREFIX + VP_ID_APIBLOCK_OPTION_IF_ARG_6 + index + uuid).addClass(VP_CLASS_STYLE_OPACITY_1);
-                // }
       
                 // RenderInputRequiredColor(VP_ID_PREFIX + VP_ID_APIBLOCK_OPTION_IF_ARG_1 + index + uuid);
                 // RenderInputRequiredColor(VP_ID_PREFIX + VP_ID_APIBLOCK_OPTION_IF_ARG_2 + index + uuid);
