@@ -33,19 +33,10 @@ define([
 
     const { PROCESS_MODE } = config;
 
-    const { RenderOptionPageContainer
-            , RenderOptionPageContainerInner
-          
-            , RenderBottomOptionTitle
-            , RenderElseBlock
-         
-            , RenderOptionPagePlusBtn
-            , RenderOptionPageDeleteBtn
+    const { GenerateListforConditionList
+            ,GenerateForParam  } = blockRenderer;
 
-            , GenerateForParam
-            , GenerateListforConditionList } = blockRenderer;
-
-            const { BLOCK_CODELINE_BTN_TYPE
+    const { BLOCK_CODELINE_BTN_TYPE
                 , BLOCK_CODELINE_TYPE
                 , FOR_BLOCK_TYPE
                 , FOR_BLOCK_ARG3_TYPE
@@ -109,7 +100,8 @@ define([
                 , VP_CLASS_STYLE_WIDTH_100PERCENT
     
                 , VP_CLASS_APIBLOCK_OPTION_INPUT
-    
+                , VP_CLASS_APIBLOCK_BLOCK_HEADER 
+
                 , VP_CLASS_STYLE_OPACITY_0
                 , VP_CLASS_STYLE_OPACITY_1
                 
@@ -172,7 +164,7 @@ define([
                     listforConditionList: listforConditionListState
                 });
                 var listforConditionCode = GenerateListforConditionList(thatBlock);
-                $(`.vp-block-header-${uuid}`).html(listforConditionCode);
+                $(VP_CLASS_PREFIX + VP_CLASS_APIBLOCK_BLOCK_HEADER + uuid).html(listforConditionCode);
             
                 blockContainerThis.renderBlockOptionTab();
             
@@ -200,7 +192,7 @@ define([
          
 
                 var listforConditionCode = GenerateListforConditionList(thatBlock);
-                $(`.vp-block-header-${uuid}`).html(listforConditionCode);
+                $(VP_CLASS_PREFIX + VP_CLASS_APIBLOCK_BLOCK_HEADER + uuid).html(listforConditionCode);
 
                 event.stopPropagation();
             });
@@ -224,7 +216,7 @@ define([
                     [STATE_listforConditionList]: listforConditionListState
                 });
                 var listforConditionCode = GenerateListforConditionList(thatBlock);
-                $(`.vp-block-header-${uuid}`).html(listforConditionCode);
+                $(VP_CLASS_PREFIX + VP_CLASS_APIBLOCK_BLOCK_HEADER + uuid).html(listforConditionCode);
 
                 event.stopPropagation();
             });
@@ -248,7 +240,7 @@ define([
                     [STATE_listforConditionList]: listforConditionListState
                 });
                 var listforConditionCode = GenerateListforConditionList(thatBlock);
-                $(`.vp-block-header-${uuid}`).html(listforConditionCode);
+                $(VP_CLASS_PREFIX + VP_CLASS_APIBLOCK_BLOCK_HEADER + uuid).html(listforConditionCode);
 
                 event.stopPropagation();
             });
@@ -274,7 +266,7 @@ define([
                             [STATE_listforConditionList]: listforConditionListState
                         });
                         var listforConditionCode = GenerateListforConditionList(thatBlock);
-                        $(`.vp-block-header-${uuid}`).html(listforConditionCode);
+                        $(VP_CLASS_PREFIX + VP_CLASS_APIBLOCK_BLOCK_HEADER + uuid).html(listforConditionCode);
                         blockContainerThis.renderBlockOptionTab();
                 }
 
@@ -299,7 +291,7 @@ define([
                 });
 
                 var listforConditionCode = GenerateListforConditionList(thatBlock);
-                $(`.vp-block-header-${uuid}`).html(listforConditionCode);
+                $(VP_CLASS_PREFIX + VP_CLASS_APIBLOCK_BLOCK_HEADER + uuid).html(listforConditionCode);
 
                 event.stopPropagation();
             });
@@ -324,7 +316,7 @@ define([
                 });
 
                 var listforConditionCode = GenerateListforConditionList(thatBlock);
-                $(`.vp-block-header-${uuid}`).html(listforConditionCode);
+                $(VP_CLASS_PREFIX + VP_CLASS_APIBLOCK_BLOCK_HEADER + uuid).html(listforConditionCode);
 
                 event.stopPropagation();
             });
@@ -350,7 +342,7 @@ define([
                 });
 
                 var listforConditionCode = GenerateListforConditionList(thatBlock);
-                $(`.vp-block-header-${uuid}`).html(listforConditionCode);
+                $(VP_CLASS_PREFIX + VP_CLASS_APIBLOCK_BLOCK_HEADER + uuid).html(listforConditionCode);
 
                 event.stopPropagation();
             });
@@ -376,7 +368,7 @@ define([
                 });
 
                 var listforConditionCode = GenerateListforConditionList(thatBlock);
-                $(`.vp-block-header-${uuid}`).html(listforConditionCode);
+                $(VP_CLASS_PREFIX + VP_CLASS_APIBLOCK_BLOCK_HEADER + uuid).html(listforConditionCode);
 
                 event.stopPropagation();
             });
@@ -384,28 +376,8 @@ define([
 
             /**
              * @event_function
-             * List for arg10 선택 변경 이벤트 함수
+             * List for arg10 autocomplete 입력 변경 이벤트 함수
              */
-            // $(document).off(STR_CHANGE, `.vp_apiblockBlockoptionListforArg10${index}${uuid}`);
-            // $(document).off(STR_CHANGE_KEYUP_PASTE, VP_ID_PREFIX + VP_ID_APIBLOCK_OPTION_LIST_FOR_ARG_10 + index + uuid);
-            // $(document).on(STR_CHANGE_KEYUP_PASTE, VP_ID_PREFIX + VP_ID_APIBLOCK_OPTION_LIST_FOR_ARG_10 + index + uuid, function(event) {
-            //     var listforConditionListState = thatBlock.getState(STATE_listforConditionList);
-            //     var listforConditionState = thatBlock.getState(STATE_listforConditionList)[index];
-
-            //     var updatedValue = {
-            //         ...listforConditionState
-            //         , arg10 :  $(this).val()
-            //     }
-
-            //     listforConditionListState = UpdateOneArrayValueAndGet(listforConditionListState, index, updatedValue);
-            //     thatBlock.setState({
-            //         listforConditionList: listforConditionListState
-            //     });
-            //     var listforConditionCode = GenerateListforConditionList(thatBlock);
-            //     $(`.vp-block-header-${uuid}`).html(listforConditionCode);
-
-            //     event.stopPropagation();
-            // });
             $(document).off(STR_CHANGE_KEYUP_PASTE, VP_ID_PREFIX + VP_ID_APIBLOCK_OPTION_LIST_FOR_ARG_10 + index + uuid);
             $(document).on(STR_CHANGE_KEYUP_PASTE, VP_ID_PREFIX + VP_ID_APIBLOCK_OPTION_LIST_FOR_ARG_10 + index + uuid, function(event) {
                 var listforConditionListState = thatBlock.getState(STATE_listforConditionList);
@@ -421,7 +393,7 @@ define([
                     listforConditionList: listforConditionListState
                 });
                 var listforConditionCode = GenerateListforConditionList(thatBlock);
-                $(`.vp-block-header-${uuid}`).html(listforConditionCode);
+                $(VP_CLASS_PREFIX + VP_CLASS_APIBLOCK_BLOCK_HEADER + uuid).html(listforConditionCode);
                 blockContainerThis.renderBlockOptionTab();
                 event.stopPropagation();
             });
@@ -442,7 +414,7 @@ define([
                 });
             
                 var listforConditionCode = GenerateListforConditionList(thatBlock);
-                $(`.vp-block-header-${uuid}`).html(listforConditionCode);
+                $(VP_CLASS_PREFIX + VP_CLASS_APIBLOCK_BLOCK_HEADER + uuid).html(listforConditionCode);
             
                 event.stopPropagation();
             });
@@ -452,7 +424,6 @@ define([
              * @event_function
              * List for arg12 선택 변경 이벤트 함수
              */
-            // $(document).off(STR_CHANGE, `.vp_apiblockBlockoptionListforArg12${index}${uuid}`);
             $(document).off(STR_CHANGE_KEYUP_PASTE, VP_ID_PREFIX + VP_ID_APIBLOCK_OPTION_LIST_FOR_ARG_12 + index + uuid);
             $(document).on(STR_CHANGE_KEYUP_PASTE, VP_ID_PREFIX + VP_ID_APIBLOCK_OPTION_LIST_FOR_ARG_12 + index + uuid, function(event) {
                 var listforConditionListState = thatBlock.getState(STATE_listforConditionList);
@@ -468,14 +439,16 @@ define([
                     listforConditionList: listforConditionListState
                 });
                 var listforConditionCode = GenerateListforConditionList(thatBlock);
-                $(`.vp-block-header-${uuid}`).html(listforConditionCode);
+                $(VP_CLASS_PREFIX + VP_CLASS_APIBLOCK_BLOCK_HEADER + uuid).html(listforConditionCode);
 
                 event.stopPropagation();
             });
 
 
-            /** List for arg13 변경 */
-            // $(document).off(STR_CHANGE_KEYUP_PASTE, `.vp_apiblockBlockoptionListforArg13${index}${uuid}`);
+            /** 
+             * @event_function
+             * List for arg13 변경 
+             */
             $(document).off(STR_CHANGE_KEYUP_PASTE, VP_ID_PREFIX + VP_ID_APIBLOCK_OPTION_LIST_FOR_ARG_13 + index + uuid);
             $(document).on(STR_CHANGE_KEYUP_PASTE, VP_ID_PREFIX + VP_ID_APIBLOCK_OPTION_LIST_FOR_ARG_13 + index + uuid, function(event) {
                 var listforConditionListState = thatBlock.getState(STATE_listforConditionList);
@@ -491,7 +464,7 @@ define([
                 });
             
                 var listforConditionCode = GenerateListforConditionList(thatBlock);
-                $(`.vp-block-header-${uuid}`).html(listforConditionCode);
+                $(VP_CLASS_PREFIX + VP_CLASS_APIBLOCK_BLOCK_HEADER + uuid).html(listforConditionCode);
             
                 event.stopPropagation();
             });
@@ -518,7 +491,7 @@ define([
                     listforConditionList: listforConditionListState
                 });
                 var listforConditionCode = GenerateListforConditionList(thatBlock);
-                $(`.vp-block-header-${uuid}`).html(listforConditionCode);
+                $(VP_CLASS_PREFIX + VP_CLASS_APIBLOCK_BLOCK_HEADER + uuid).html(listforConditionCode);
 
                 event.stopPropagation();
             });
@@ -543,7 +516,7 @@ define([
                 });
             
                 var listforConditionCode = GenerateListforConditionList(thatBlock);
-                $(`.vp-block-header-${uuid}`).html(listforConditionCode);
+                $(VP_CLASS_PREFIX + VP_CLASS_APIBLOCK_BLOCK_HEADER + uuid).html(listforConditionCode);
             
                 event.stopPropagation();
             });
@@ -560,7 +533,6 @@ define([
             var listforConditionLength = listforConditionListState.length;
 
             thatBlock.addVariableIndex();
-            // var variableIndex = thatBlock.getVariableIndex();
             
             var newCondition = {
                 arg1:  ''
@@ -589,7 +561,7 @@ define([
             });
 
             var listforfConditionCode = GenerateListforConditionList(thatBlock);
-            $(`.vp-block-header-${uuid}`).html(listforfConditionCode);
+            $(VP_CLASS_PREFIX + VP_CLASS_APIBLOCK_BLOCK_HEADER + uuid).html(listforfConditionCode);
 
             blockContainerThis.renderBlockOptionTab();
         });
@@ -605,7 +577,7 @@ define([
             });
 
             var listforfConditionCode = GenerateListforConditionList(thatBlock);
-            $(`.vp-block-header-${uuid}`).html(listforfConditionCode);
+            $(VP_CLASS_PREFIX + VP_CLASS_APIBLOCK_BLOCK_HEADER + uuid).html(listforfConditionCode);
 
             event.stopPropagation();
         });
@@ -621,7 +593,7 @@ define([
             });
 
             var listforfConditionCode = GenerateListforConditionList(thatBlock);
-            $(`.vp-block-header-${uuid}`).html(listforfConditionCode);
+            $(VP_CLASS_PREFIX + VP_CLASS_APIBLOCK_BLOCK_HEADER + uuid).html(listforfConditionCode);
 
             event.stopPropagation();
         });
@@ -640,11 +612,11 @@ define([
 
             if ( selectedVal == FOR_BLOCK_TYPE.FOR ) {
                 var forParamStr = GenerateForParam(thatBlock);
-                $(`.vp-block-header-${thatBlock.getUUID()}`).html(forParamStr);
+                $(VP_CLASS_PREFIX + VP_CLASS_APIBLOCK_BLOCK_HEADER + uuid).html(forParamStr);
                 thatBlock.getBlockHeaderDom().find(STR_STRONG).css(STR_DISPLAY, STR_FLEX);
             } else {
                 var listForStr = GenerateListforConditionList(thatBlock);
-                $(`.vp-block-header-${thatBlock.getUUID()}`).html(listForStr);
+                $(VP_CLASS_PREFIX + VP_CLASS_APIBLOCK_BLOCK_HEADER + uuid).html(listForStr);
                 thatBlock.getBlockHeaderDom().find(STR_STRONG).css(STR_DISPLAY, STR_NONE);
             }
 
@@ -750,14 +722,14 @@ define([
                     listforReturnVar: selectedValue
                 });
                 var listforConditionCode = GenerateListforConditionList(thatBlock);
-                $(`.vp-block-header-${uuid}`).html(listforConditionCode);
+                $(VP_CLASS_PREFIX + VP_CLASS_APIBLOCK_BLOCK_HEADER + uuid).html(listforConditionCode);
                 return;
             } else if (FOR_BLOCK_SELECT_VALUE_ARG_TYPE.PREV_EXPRESSION == argType) {
                 thatBlock.setState({
                     listforPrevExpression: selectedValue
                 });
                 var listforConditionCode = GenerateListforConditionList(thatBlock);
-                $(`.vp-block-header-${uuid}`).html(listforConditionCode);
+                $(VP_CLASS_PREFIX + VP_CLASS_APIBLOCK_BLOCK_HEADER + uuid).html(listforConditionCode);
                 return;
             }
         
@@ -767,7 +739,7 @@ define([
             });
         
             var listforConditionCode = GenerateListforConditionList(thatBlock);
-            $(`.vp-block-header-${uuid}`).html(listforConditionCode);
+            $(VP_CLASS_PREFIX + VP_CLASS_APIBLOCK_BLOCK_HEADER + uuid).html(listforConditionCode);
 
             if (FOR_BLOCK_SELECT_VALUE_ARG_TYPE.ARG3 == argType) {
                 $(document).off(STR_CHANGE_KEYUP_PASTE, VP_ID_PREFIX + VP_ID_APIBLOCK_OPTION_LIST_FOR_ARG_3 + index+ uuid);
@@ -891,8 +863,8 @@ define([
                 const { arg1, arg2, arg3, arg4, arg5, arg6, arg7,
                         arg10, arg11, arg12, arg13, arg14, arg15 } = listforParam;
                 var loadedVariableNameList = blockContainerThis.getKernelLoadedVariableNameList();
-                var loadedVariableNameList_arg1 = [ ...loadedVariableNameList,  `'i${index + 1}'`];
-                var loadedVariableNameList_arg4 = [ ...loadedVariableNameList,  `'j${index + 1}'`];
+                var loadedVariableNameList_arg1 = [ ...loadedVariableNameList,  `i${index + 1}`];
+                var loadedVariableNameList_arg4 = [ ...loadedVariableNameList,  `j${index + 1}`];
                 var loadedVariableNameList_arg3 = [ ...Object.values( FOR_BLOCK_ARG3_TYPE )];
                 /** 0,1,2,3 */
                 var loadedVariableNameList_arg5 = [ ...loadedVariableNameList, '0','1','2','3'];
@@ -984,41 +956,24 @@ define([
                 sbListForCondition2ArgContainer.appendFormatLine("<div class='{0} {1}'>", VP_CLASS_STYLE_FLEX_ROW_BETWEEN 
                                                                             , VP_CLASS_STYLE_WIDTH_80PERCENT);
 
+                var sbforParamArg3 = MakeVpSuggestInputText_apiblock(VP_ID_APIBLOCK_OPTION_LIST_FOR_ARG_3 + index + uuid
+                                                                    , arg3
+                                                                    , loadedVariableNameList_arg3
+                                                                    , VP_CLASS_STYLE_WIDTH_40PERCENT
+                                                                    , 'Method'
+                                                                    , function(selectedValue) {
+                                                                        bindSelectValueEventFunc_for(selectedValue, 
+                                                                            index
+                                                                            ,FOR_BLOCK_SELECT_VALUE_ARG_TYPE.ARG3);
+                                                                    });    
 
-                // var sbforParamArg3 = MakeVpSuggestInputText_apiblock(VP_ID_APIBLOCK_OPTION_LIST_FOR_ARG_3 + index + uuid
-                //                                                             ,arg3
-                //                                                             ,loadedVariableNameList_arg3
-                //                                                             , VP_CLASS_STYLE_WIDTH_40PERCENT
-                //                                                             , 'Method'
-                //                                                             , function(selectedValue) {
-                //                                                                 bindSelectValueEventFunc_for(selectedValue, 
-                //                                                                     index
-                //                                                                     ,FOR_BLOCK_SELECT_VALUE_ARG_TYPE.ARG3);
-                //                                                             });
-     
-                // sbListForCondition2ArgContainer.appendLine(sbforParamArg3);
-                var sbforParamArg3; 
+                sbListForCondition2ArgContainer.appendLine(sbforParamArg3);
+                // var sbforParamArg3; 
                 if (arg3 == FOR_BLOCK_ARG3_TYPE.ZIP 
                     || arg3 == FOR_BLOCK_ARG3_TYPE.RANGE 
                     || arg3 == FOR_BLOCK_ARG3_TYPE.ENUMERATE) {
-                        sbforParamArg3 = MakeOptionSelectBox(VP_ID_APIBLOCK_OPTION_LIST_FOR_ARG_3  + index + uuid
-                                                            , VP_CLASS_STYLE_WIDTH_40PERCENT
-                                                            , arg3
-                                                            , loadedVariableNameList_arg3);
-                    sbListForCondition2ArgContainer.appendLine(sbforParamArg3);
-                } else {
-        
-                    sbforParamArg3 = MakeVpSuggestInputText_apiblock(VP_ID_APIBLOCK_OPTION_LIST_FOR_ARG_3 + index + uuid
-                                                                        , arg3
-                                                                        , loadedVariableNameList_arg3
-                                                                        , VP_CLASS_STYLE_WIDTH_40PERCENT
-                                                                        , 'Method'
-                                                                        , function(selectedValue) {
-                                                                            bindSelectValueEventFunc_for(selectedValue, 
-                                                                                index
-                                                                                ,FOR_BLOCK_SELECT_VALUE_ARG_TYPE.ARG3);
-                                                                        });                
-    
+
+                } else{
                     var sbforParamArg2 = MakeVpSuggestInputText_apiblock(VP_ID_APIBLOCK_OPTION_LIST_FOR_ARG_2  + index + uuid
                                                                             ,arg2
                                                                             ,loadedVariableNameList_arg2
@@ -1029,8 +984,7 @@ define([
                                                                                     , index
                                                                                     , FOR_BLOCK_SELECT_VALUE_ARG_TYPE.ARG2);
                                                                             });
-                    sbListForCondition2ArgContainer.appendLine(sbforParamArg3);
-                    sbListForCondition2ArgContainer.appendLine(sbforParamArg2);                                                            
+                    sbListForCondition2ArgContainer.appendLine(sbforParamArg2);   
                 }
 
                 if (arg3 == FOR_BLOCK_ARG3_TYPE.RANGE) {
@@ -1112,16 +1066,7 @@ define([
                                         , VP_CLASS_STYLE_WIDTH_15PERCENT
                                         , arg10
                                         , loadedVariableNameList_arg10);
-                // var suggestInputArg10 =  MakeVpSuggestInputText_apiblock(VP_ID_APIBLOCK_OPTION_LIST_FOR_ARG_10 + index + uuid
-                //                                                         , arg10
-                //                                                         , loadedVariableNameList_arg10
-                //                                                         , VP_CLASS_STYLE_WIDTH_15PERCENT
-                //                                                         , 'Select'
-                //                                                         , function(selectedValue) {
-                //                                                             bindSelectValueEventFunc_for(selectedValue, 
-                //                                                                                         index,
-                //                                                                                         FOR_BLOCK_SELECT_VALUE_ARG_TYPE.ARG10);
-                //                                                             }); 
+   
                 sbListForCondition3.appendLine(suggestInputArg10);
         
                 if (arg10 == 'if') {
@@ -1210,10 +1155,6 @@ define([
             forBlockOption.append(plusButton);
 
             $(optionPageSelector).append(forBlockOption);
-            // , STATE_listforReturnVar
-            // , STATE_listforPrevExpression
-            // var listforConditionListState = thatBlock.getState(STATE_listforReturnVar);
-            // var listforConditionListState = thatBlock.getState(STATE_listforPrevExpression);
 
             $(VP_ID_PREFIX + VP_ID_APIBLOCK_OPTION_LIST_FOR_RETURN_VAR + uuid).val(listforReturnVarState);
             $(VP_ID_PREFIX + VP_ID_APIBLOCK_OPTION_LIST_FOR_PREV_EXPRESSION + uuid).val(listforPrevExpression);
