@@ -451,9 +451,9 @@ define([
             var code = new sb.StringBuilder();
             code.appendLine('import json');
             if (varType == 'DataFrame') {
-                code.append(`print(json.dumps([ { "colName": c, "dtype": str(${varName}[c].dtype), "array": str(${varName}[c].array) } for c in list(${varName}.columns) ]))`);
+                code.appendFormat(`print(json.dumps([ { "colName": c, "dtype": str({0}[c].dtype), "array": str({1}[c].array) } for c in list({2}.columns) ]))`, varName, varName, varName);
             } else if (varType == 'Series') {
-                code.append(`print(json.dumps({"dtype": str(${varName}.dtype), "array": str(${varName}.array) }))`);
+                code.appendFormat(`print(json.dumps({"dtype": str({0}.dtype), "array": str({1}.array) }))`, varName, varName);
             }
 
             // get result and show on detail box
@@ -786,9 +786,11 @@ define([
 
             // 색상 사용 안하면 코드에 표시되지 않도록
             if ($(this.wrapSelector('#useColor')).prop('checked') != true) {
-                var idx = package.variable.findIndex(function(item) {return item.name === 'color'});
-                if (idx > -1) {
-                    package.variable.splice(idx, 1);
+                if (package.variable != undefined) {
+                    var idx = package.variable.findIndex(function(item) {return item.name === 'color'});
+                    if (idx > -1) {
+                        package.variable.splice(idx, 1);
+                    }
                 }
             }
 
@@ -1312,7 +1314,7 @@ define([
                         type: 'var',
                         label: 'y data'
                     }
-                ],
+                ]
             }
         };
         
