@@ -1,13 +1,8 @@
 define ([
-    'require'
-    , 'nbextensions/visualpython/src/common/vpCommon'
-    // numpy 패키지를 위한 라이브러리import 
-    , 'nbextensions/visualpython/src/common/constant_numpy'
-    , 'nbextensions/visualpython/src/numpy/common/NumpyPageRender/parent/NumpyPageRender'
-], function( requirejs, vpCommon, 
-             vpNumpyConst, NumpyPageRender ) {
+    'nbextensions/visualpython/src/numpy/common/NumpyPageRender/parent/NumpyPageRender'
+], function( NumpyPageRender ) {
 
-    "use strict";
+    'use strict';
     /**
      * @class NpDstackHstackVstackPageRender
      * @constructor
@@ -37,48 +32,48 @@ define ([
         var numpyPageRenderThis = this;
         const {  PARAM_INPUT_EDITOR_TYPE, PARAM_ONE_ARRAY_INDEX_N_EDITOR_TYPE } = this.numpyEnumRenderEditorFuncType;
         // state의 paramData 객체의 키값을 string 배열로 리턴
-        var stateParamNameStrArray = Object.keys(this.numpyStateGenerator.getState("paramData"));
-        var tabTitle = "Input Stacking Array";
+        var stateParamNameStrArray = Object.keys(this.numpyStateGenerator.getState('paramData'));
+        var tabTitle = 'Input Stacking Array';
         var tabBlockArray = [
             {
                 tabNumber: 1
-                , btnText: "1개 배열 합치기"
+                , btnText: '1개 배열 합치기'
                 , bindFuncData: {
                     numpyPageRenderThis: numpyPageRenderThis
                     , numpyPageRenderFuncType: PARAM_INPUT_EDITOR_TYPE
                     , stateParamNameStrOrStrArray: [stateParamNameStrArray[0]]
-                    , paramNameStrArray: [ "배열" ]
-                    , placeHolderArray: [ "변수 입력"  ]
+                    , paramNameStrArray: [ '배열' ]
+                    , placeHolderArray: [ '변수 입력'  ]
                 }
           
             },
             {
                 tabNumber: 2
-                , btnText: "2개 배열 합치기"
+                , btnText: '2개 배열 합치기'
                 , bindFuncData: {
                     numpyPageRenderThis: numpyPageRenderThis
                     , numpyPageRenderFuncType: PARAM_INPUT_EDITOR_TYPE
                     , stateParamNameStrOrStrArray: [ stateParamNameStrArray[1], stateParamNameStrArray[2]]
-                    , paramNameStrArray: [ "배열",  "배열"  ]
-                    , placeHolderArray: [ "변수 입력", "변수 입력" ]
+                    , paramNameStrArray: [ '배열',  '배열'  ]
+                    , placeHolderArray: [ '변수 입력', '변수 입력' ]
                 }
                
             },
             {
                 tabNumber: 3
-                , btnText: "3개 배열 합치기"
+                , btnText: '3개 배열 합치기'
                 , bindFuncData: {
                     numpyPageRenderThis: numpyPageRenderThis
                     , numpyPageRenderFuncType: PARAM_INPUT_EDITOR_TYPE
                     , stateParamNameStrOrStrArray:  [ stateParamNameStrArray[3], stateParamNameStrArray[4], stateParamNameStrArray[5]]
-                    , paramNameStrArray: [ "배열",  "배열", "배열"  ]
-                    , placeHolderArray: [ "변수 입력", "변수 입력", "변수 입력" ]
+                    , paramNameStrArray: [ '배열',  '배열', '배열'  ]
+                    , placeHolderArray: [ '변수 입력', '변수 입력', '변수 입력' ]
                 }
            
             },
             {
                 tabNumber: 4
-                , btnText: "N개 배열 합치기"
+                , btnText: 'N개 배열 합치기'
                 , bindFuncData: {
                     numpyPageRenderThis: numpyPageRenderThis
                     , numpyPageRenderFuncType: PARAM_ONE_ARRAY_INDEX_N_EDITOR_TYPE
